@@ -7,13 +7,11 @@ import re
 import click
 from click import Context
 
-from textwatermark import __version__
-from textwatermark.config import settings
-from textwatermark.defines import WMMethod, WMMode
-from textwatermark.main import TextWatermark
-from textwatermark.template_type import WMTemplateType
-
-# from textwatermark.log import init_log
+from . import __version__
+from .config import settings
+from .defines import WMMethod, WMMode
+from .main import TextWatermark
+from .template_type import WMTemplateType
 
 
 @click.group(invoke_without_command=True)
